@@ -39,6 +39,7 @@
 extern "C" {
 #endif
 
+typedef struct _EnchantProviderDict EnchantProviderDict;
 typedef struct _EnchantProvider EnchantProvider;
 
 /**
@@ -113,14 +114,14 @@ char *enchant_get_prefix_dir(void);
 char *enchant_relocate (const char *path);
 
 /**
- * enchant_dict_new
+ * enchant_provider_dict_new
  * @provider: A provider, or %null.
  * @tag: The language tag, or a description, for a non-language-specific
  * dictionary.
  *
- * Returns a new EnchantDict.
+ * Returns a new EnchantProviderDict.
  */
-EnchantDict *enchant_dict_new (EnchantProvider *provider, const char *tag);
+EnchantProviderDict *enchant_provider_dict_new (EnchantProvider *provider, const char *tag);
 
 /**
  * enchant_dict_set_error
@@ -128,10 +129,19 @@ EnchantDict *enchant_dict_new (EnchantProvider *provider, const char *tag);
  * @err: A non-null error message
  *
  * Sets the current runtime error to @err. This API is private to the
- * providers.
+ * providers, and only used for testing.
  */
 void enchant_dict_set_error (EnchantDict * dict, const char * const err);
 
+/**
+ * enchant_dict_set_error
+ * @dict: A non-null dictionary
+ * @err: A non-null error message
+ *
+ * Sets the current runtime error to @err.
+ */
+void enchant_provider_dict_set_error (EnchantProviderDict * dict, const char * const err);
+
 /**
  * enchant_provider_new
  *
@@ -149,34 +159,52 @@ EnchantProvider *enchant_provider_new (void);
  */
 void enchant_provider_set_error (EnchantProvider * provider, const char * const err);
 
-typedef struct _EnchantDictPrivate *EnchantDictPrivate;
+typedef struct _EnchantProviderDictPrivate *EnchantProviderDictPrivate;
 
-struct _EnchantDict
+struct _EnchantProviderDict
 {
 	GTypeInstance parent_instance;
 	volatile int ref_count;
-	EnchantDictPrivate * priv;
+	EnchantProviderDictPrivate * priv;
 	void *user_data;
-	void *enchant_private_data;
+	EnchantProvider *provider;
+	gchar *language_tag;
+	gchar *error;
 
-	int (*check) (struct _EnchantDict * me, const char *const word,
+	// Implement enchant_dict_check for the given provider dictionary.
+	// This method is mandatory.
+	int (*check) (struct _EnchantProviderDict * me, const char *const word,
 			  size_t len);
 
-	/* Returns an array of *out_n_suggs UTF-8 encoded strings. Elements
-	   of word may be NULL. */
-	char **(*suggest) (struct _EnchantDict * me,
+	// Implement enchant_dict_suggest for the given provider dictionary.
+	// Returns an array of *out_n_suggs UTF-8 encoded strings. Elements
+	// of word may be NULL.
+	// This method is mandatory.
+	char **(*suggest) (struct _EnchantProviderDict * me,
 			   const char *const word, size_t len,
 			   size_t * out_n_suggs);
 
-	void (*add_to_session) (struct _EnchantDict * me,
+	// Implement enchant_dict_add_to_session for the given provider
+	// dictionary.
+	// This method is optional.
+	void (*add_to_session) (struct _EnchantProviderDict * me,
 				const char *const word, size_t len);
 
-	void (*remove_from_session) (struct _EnchantDict * me,
+	// Implement enchant_dict_remove_from_session for the given provider
+	// dictionary.
+	// This method is optional.
+	void (*remove_from_session) (struct _EnchantProviderDict * me,
 				const char *const word, size_t len);
 
-	const char * (*get_extra_word_characters) (struct _EnchantDict * me);
+	// Implement enchant_dict_get_extra_word_characters for the given
+	// provider dictionary.
+	// This method is optional.
+	const char * (*get_extra_word_characters) (struct _EnchantProviderDict * me);
 
-	int (*is_word_character) (struct _EnchantDict * me,
+	// Implement enchant_dict_is_word_character for the given provider
+	// dictionary.
+	// This method is optional.
+	int (*is_word_character) (struct _EnchantProviderDict * me,
 				  uint32_t uc_in, size_t n);
 };
 
@@ -190,36 +218,42 @@ struct _EnchantProvider {
 	void* enchant_private_data;
 	EnchantBroker* owner;
 
+	// Free any resources associated with this provider.
+	// This method is mandatory.
 	void (*dispose) (struct _EnchantProvider * me);
 
-	EnchantDict *(*request_dict) (struct _EnchantProvider * me,
+	// Return a provider dictionary for the given language tag, or NULL if
+	// no suitable dictionary can be found.
+	// This method is mandatory.
+	EnchantProviderDict *(*request_dict) (struct _EnchantProvider * me,
 				      const char *const tag);
 
+	// Free any resources associated with the given provider dictionary.
+	// This method is mandatory.
 	void (*dispose_dict) (struct _EnchantProvider * me,
-			      EnchantDict * dict);
+			      EnchantProviderDict * dict);
 
+	// Return 1 if a dictionary for the given tag exists, or 0 if not.
+	// This method is optional.
 	int (*dictionary_exists) (struct _EnchantProvider * me,
 				  const char *const tag);
 
-	/* returns utf8*/
+	// Return a UTF-8 string identifying the provider. This string should
+	// be a single word, without spaces.
+	// This method is mandatory.
 	const char * (*identify) (struct _EnchantProvider * me);
-	/* returns utf8*/
+
+	// Return a UTF-8 string describing the provider.
+	// This method is mandatory.
 	const  char * (*describe) (struct _EnchantProvider * me);
 
-	/* Returns an array of *out_n_dicts dictionary tags. Elements
-	   of word may be NULL. */
+	// Return an array of *out_n_dicts dictionary tags. Elements
+	// of word may be NULL.
+	// This method is mandatory.
 	char ** (*list_dicts) (struct _EnchantProvider * me,
 			       size_t * out_n_dicts);
 };
 
-/**
- * composite_provider_create_dict
- * @list_of_dicts: A non-null list of #EnchantDicts
- *
- * Creates a composite dictionary of EnchantDicts in @list_of_dicts
- */
-EnchantDict *composite_provider_create_dict (GSList *dicts);
-
 #ifdef __cplusplus
 }
 #endif
